@@ -46,6 +46,7 @@ from lxml import etree as et
 from functools import partial
 from datetime import datetime
 from dateutil.parser import parse as dparse
+from io import FileIO
 from operator import itemgetter
 from uuid import uuid4 as uuid
 from copy import deepcopy
@@ -56,6 +57,8 @@ import bz2
 import itertools
 import hashlib
 import logging
+import os
+import os.path
 import pkg_resources
 
 import kenozooid
@@ -80,8 +83,16 @@ FMT_DT = lambda dt: format(dt, '%Y-%m-%dT%H:%M:%S%z')
 # Parsing and searching.
 #
 
-# XPath query constructor for UDDF data.
 XPath = partial(et.XPath, namespaces=_NSMAP)
+XPath.__doc__ = """
+    XPath query constructor for UDDF data.
+
+    Use `uddf` prefix to create a query, i.e.::
+
+        XPath('uddf:informationbeforedive/uddf:datetime/text()')
+
+    .. seealso: lxml.etree.XPath
+"""
 
 # XPath queries for default dive data
 XP_DEFAULT_DIVE_DATA = (
@@ -173,13 +184,44 @@ class RangeError(ValueError):
     pass
 
 
-def parse(f, query, **params):
+def parse(f, ver_check=True):
+    """
+    Parse XML file and return document object.
+
+    File to parse can be anything supported by ``lxml`` library.
+
+    If file to parse is file name and ends with '.bz2', then it is treated
+    as file compressed with bzip2.
+
+    :Parameters:
+     f
+        File to parse.
+     ver_check
+        Check version of UDDF file.
+    """
+    if isinstance(f, str) and (f.endswith('.bz2') or f.endswith('.bz2.bak')):
+        log.debug('detected compressed file')
+        f = bz2.BZ2File(f)
+    doc = et.parse(f)
+    if ver_check:
+        v1, v2, *_ = doc.getroot().get('version').split('.')
+        if (v1, v2) != ('3', '1'):
+            raise ValueError('UDDF file version {}.{} is not supported.' \
+                    ' Please upgrade file with "kz upgrade" command.' \
+                    .format(v1, v2))
+    return doc
+
+
+def find(f, query, **params):
     """
     Find XML nodes in UDDF file using XPath query.
 
     UDDF file can be a file name, file object, URL and basically everything
     what is supported by `lxml` library.
 
+    File to parse can be a file name ending with '.bz2'. It is treated as
+    file compressed with bzip2.
+
     :Parameters:
      f
         UDDF file to parse.
@@ -188,12 +230,11 @@ def parse(f, query, **params):
      params
         XPath query parameters.
 
-    .. seealso::
-        XPath
+    .. seealso:: :py:func:`XPath`, :py:func:`parse`
     """
     log.debug('parsing and searching with query: {}; parameters {}' \
             .format(query, params))
-    doc = et.parse(f)
+    doc = parse(f)
     if isinstance(query, str):
         return xp(doc, query)
     else:
@@ -296,9 +337,7 @@ def find_data(name, node, fields, queries, parsers, nquery=None):
         XPath expression object to relocate from node to more appropriate
         position in XML document for record data retrieval.
 
-    .. seealso::
-        dive_data
-        dive_profile
+    .. seealso:: :py:func:`dive_data`, :py:func:`dive_profile`
     """
     T = namedtuple(name, ' '.join(fields))._make
     if nquery:
@@ -329,8 +368,7 @@ def dive_data(node, fields=None, queries=None, parsers=None):
      parsers
         Parsers field values to be created in a record.
 
-    .. seealso::
-        find_data
+    .. seealso:: :py:func:`find_data`
     """
     if fields is None:
         fields = ('datetime', 'depth', 'duration', 'temp', 'avg_depth')
@@ -366,8 +404,7 @@ def dive_profile(node, fields=None, queries=None, parsers=None):
      parsers
         Parsers of field values to be created in a record.
 
-    .. seealso::
-        find_data
+    .. seealso:: :py:func:`find_data`
     """
     if fields is None:
         fields = ('depth', 'time', 'temp', 'setpoint', 'setpointby',
@@ -415,8 +452,7 @@ def dump_data(node, fields=None, queries=None, parsers=None):
      parsers
         Parsers of field values to be created in a record.
 
-    .. seealso::
-        find_data
+    .. seealso:: :py:func:`find_data`
     """
     if fields is None:
         fields = ('dc_id', 'dc_model', 'datetime', 'data')
@@ -454,8 +490,7 @@ def buddy_data(node, fields=None, queries=None, parsers=None):
      parsers
         Parsers of field values to be created in a record.
 
-    .. seealso::
-        find_data
+    .. seealso:: :py:func:`find_data`
     """
     if fields is None:
         fields = ('id', 'fname', 'mname', 'lname', 'org', 'number')
@@ -491,8 +526,7 @@ def site_data(node, fields=None, queries=None, parsers=None):
      parsers
         Parsers of field values to be created in a record.
 
-    .. seealso::
-        find_data
+    .. seealso:: :py:func:`find_data`
     """
     if fields is None:
         fields = ('id', 'name', 'location', 'x', 'y')
@@ -650,45 +684,6 @@ def create(datetime=datetime.now()):
     return root
 
 
-def save(doc, f, validate=True):
-    """
-    fixme: obsolete
-
-    Save UDDF data to a file.
-
-    A file can be a file name, file like object or anything supported by
-    `lxml` for writing.
-
-    :Parameters:
-     doc
-        UDDF document to save.
-     f
-        UDDF output file.
-     validate
-        Validate UDDF file before saving if set to True.
-    """
-    log.debug('cleaning uddf file')
-    #et.deannotate(doc)
-    et.cleanup_namespaces(doc)
-
-    if validate:
-        log.debug('validating uddf file')
-        fs = pkg_resources.resource_stream('kenozooid', 'uddf/uddf_3.1.0.xsd')
-        if hasattr(fs, 'name'):
-            log.debug('uddf xsd found: {}'.format(fs.name))
-        schema = et.XMLSchema(et.parse(fs))
-        try:
-            schema.assertValid(doc)
-        except et.DocumentInvalid as ex:
-            log.info(et.tostring(doc, pretty_print=True))
-            raise ex
-
-    et.ElementTree(doc).write(f,
-            encoding='utf-8',
-            xml_declaration=True,
-            pretty_print=True)
-
-
 def set_data(node, queries, formatters=None, **data):
     """
     Set data of nodes or attributes using XPath queries relative to
@@ -1078,10 +1073,18 @@ def create_dump_data(dc_id, datetime, data):
     )
 
 
-def save_uddf(doc, fout, validate=True):
+def save(doc, fout, validate=True):
     """
     Save UDDF XML data into a file.
 
+    If output file is file name ending with '.bz2', then it is compressed
+    with bzip2.
+
+    The UDDF XML data can be ElementTree XML object or iterable of strings.
+
+    If output file exists then backup file with ``.bak`` extension is
+    created.
+
     :Parameters:
      doc
         UDDF XML data.
@@ -1091,17 +1094,44 @@ def save_uddf(doc, fout, validate=True):
         Validate UDDF file after saving if True.
     """
     log.debug('saving uddf file')
-    with open(fout, 'w') as f:
-        f.writelines(doc)
+    is_fn = isinstance(fout, str)
+    openf = open
+    if is_fn and fout.endswith('.bz2'):
+        openf = bz2.BZ2File
+        log.debug('uddf file will be compressed')
 
-    if validate:
-        log.debug('validating uddf file')
-        fs = pkg_resources.resource_stream('kenozooid', 'uddf/uddf_3.1.0.xsd')
-        if hasattr(fs, 'name'):
-            log.debug('uddf xsd found: {}'.format(fs.name))
-        schema = et.XMLSchema(et.parse(fs))
-        schema.assertValid(et.parse(fout))
-        log.debug('uddf file is valid')
+    fbk = '{}.bak'.format(fout)
+    if is_fn and os.path.exists(fout):
+        os.rename(fout, fbk)
+        log.debug('backup file created')
+    try:
+        f = openf(fout, 'w') if is_fn else fout
+
+        if et.iselement(doc):
+            et.ElementTree(doc).write(f,
+                    encoding='utf-8',
+                    xml_declaration=True,
+                    pretty_print=True)
+        else:
+            f.writelines(l.encode('utf-8') for l in doc)
+
+        if validate:
+            log.debug('validating uddf file')
+            fs = pkg_resources.resource_stream('kenozooid', 'uddf/uddf_3.1.0.xsd')
+            if hasattr(fs, 'name'):
+                log.debug('uddf xsd found: {}'.format(fs.name))
+            schema = et.XMLSchema(et.parse(fs))
+            if is_fn:
+                f = openf(fout)
+            else:
+                f.seek(0)
+            schema.assertValid(et.parse(f))
+            log.debug('uddf file is valid')
+    except Exception as ex:
+        if os.path.exists(fbk):
+            os.rename(fbk, fout)
+            log.debug('backup file restored')
+        raise ex
 
 
 #
@@ -1281,9 +1311,11 @@ def get_version(f):
      f
         File to check.
     """
-    n = et.parse(f).getroot()
+    n = parse(f, ver_check=False).getroot()
     v1, v2, *_ = n.get('version').split('.')
-    f.seek(0, 0)
+    if isinstance(f, FileIO):
+        f.seek(0, 0)
+    log.debug('detected version {}.{}'.format(v1, v2))
     return int(v1), int(v2)
 
 
